/*

LargeIcons demo by ACWraith

This source should demonstrate a way to display icons larger than 32x32 pixels
using a finite number of images instead of extra atoms.  The result will obey
changes in direction just like a 32x32 icon and can be flicked.

*/




//	I tend to find it much cleaner to use a single global overlay.
//	You can reuse it so you won't have to keep creating images.
//	It's kind of pointless in this demo since it is likely to only be used once.
//	However, it could be handy in a large project where instances are limited.
var/image/gOverlay
world/New()
	if (gOverlay)	return

	//	Use the default image arguments.
	//	You're going to want the overlay to obey the base object's vars.
	gOverlay	= image(null)

	//	Of course, the overlay should count for multiple 32x32 pixel sections.
	//	Images have their own overlays so we can add sections to it once and
	//	then only have to deal with the single image container later.
	//
	//	7x7 tiles might be to large for you, but it makes a nice maximum.
	var
		image/I	= image(null)
		X
		Y
	for(X = 1 to 7)
		I.pixel_x				= X*32 - 128
		for(Y = 1 to 7)
			I.pixel_y			= Y*32 - 128
			I.icon_state		= "[X-1],[Y-1]"
			gOverlay.overlays	+= I




//	You want the object using the overlay to be on the lowest layer.
//	Otherwise, a small version of the icon could be shown in the center.
//	(You probably don't have to worry if the icon is opaque though.)
mob
	layer	= AREA_LAYER
area
	layer	= AREA_LAYER+1
	//	Make the layer above opaque to hide the one below.
	icon	= 'area.dmi'





//	As you may have noticed from above, we'll be using a mob for this demo.
//	The same rules should apply for any atom though.
mob
	//	Add a large icon.
	//	I'm using 4 directional icons, but 1 or 8 will work fine.
	icon	= 'normal.dmi'

	//	Add the overlay containing the coordinate states.
	New(Loc)
		..(Loc)
		//	If you hid the layer as I have done in this demo,
		//	then you'll want to set the global overlay to a visible layer.
		gOverlay.layer	= MOB_LAYER+1
		src.overlays	+= gOverlay





	//	Large icons can be flicked.
	//	The catch is that you have to use a separate icon rather than a state.
	verb
		Flick_Me()
			flick('flick.dmi',src)
